@@ -82,7 +82,7 @@ import requests
 from packaging.version import parse
 from yarl import URL
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 class VersionWarning(Warning):
@@ -364,8 +364,15 @@ To safely reproduce please use hash_algo="{hash_algo}", hash_value="{this_hash}"
 
         # couldn't find any installed package
         if not spec:
-            if not auto_install:
-                return fail_or_default(default, ImportError, f"{name} is not installed and auto-install was not requested.")
+            # builtins may have no spec, let's not mess with those
+            if not auto_install and not spec.parent:
+                try:
+                    mod = importlib.import_module(name)
+                    # not using build_mod, so we need to do this from here
+                    for (check, pattern), decorator in aspectize.items():
+                        apply_aspect(mod, check, pattern, decorator)
+                except ImportError:
+                    return fail_or_default(default, ImportError, f"{name} is not installed and auto-install was not requested.")
 
             # TODO: raise appropriate detailed warnings and give helpful info from the json to fix the issue
             if not (version and hash_value):
@@ -404,15 +411,8 @@ To safely reproduce please use hash_algo="{hash_algo}", hash_value="{this_hash}"
             spec = importlib.machinery.PathFinder.find_spec(name)
 
         # now there should be a valid spec defined
+        mod = build_mod(name, spec.loader.get_source(name), initial_globals, aspectize=aspectize)
 
-        # builtins may have no spec, let's not mess with those
-        if not spec or spec.parent:
-            mod = importlib.import_module(name)
-            # not using build_mod, so we need to do this from here
-            for (check, pattern), decorator in aspectize.items():
-                apply_aspect(mod, check, pattern, decorator)
-        else:
-            mod = build_mod(name, spec.loader.get_source(name), initial_globals, aspectize=aspectize)
         self.__using[name] = mod, spec, inspect.getframeinfo(inspect.currentframe())
 
         if version:
